﻿using System;
using System.Globalization;
using Telerik.Windows.Controls.Map;

namespace UsingDeepZoomComposerImages
{
	public class DeepZoomTileSource : TiledMapSource
	{
		private string tileUriFormat;

		/// <summary>
		/// Initializes a new instance of the DeepZoomTileSource class.
		/// </summary>
		/// <param name="tileUriFormat">Format string to access deep zoom tiles.</param>
		public DeepZoomTileSource(string tileUriFormat)
			: base(1, 20, 256, 256)
		{
			this.tileUriFormat = tileUriFormat;
		}

		/// <summary>
		/// Initialize provider.
		/// </summary>
		public override void Initialize()
		{
			// Raise provider intialized event.
			this.RaiseIntializeCompleted();
		}

		/// <summary>
		/// Gets the image URI.
		/// </summary>
		/// <param name="tileLevel">Tile level.</param>
		/// <param name="tilePositionX">Tile X.</param>
		/// <param name="tilePositionY">Tile Y.</param>
		/// <returns>URI of image.</returns>
		protected override Uri GetTile(int tileLevel, int tilePositionX, int tilePositionY)
		{
			string url = this.tileUriFormat.Replace("{zoom}", tileLevel.ToString(CultureInfo.InvariantCulture));
			url = url.Replace("{x}", tilePositionX.ToString(CultureInfo.InvariantCulture));
			url = url.Replace("{y}", tilePositionY.ToString(CultureInfo.InvariantCulture));

			return new Uri(url);
		}

	}
}
